@@ -149,7 +149,7 @@ sub ISO2English
 =item Xlat
 
 Translates its (English) argument to the language specified by the
-current value of C<$gobal-E<gt>{language}>. The module, in its source
+current value of C<$global-E<gt>{language}>. The module, in its source
 file, contains a data structure, indexed by the English strings, that
 has all available translations.
 
