@@ -63,18 +63,16 @@ void usage()
 }
 
 static
-void input_error(num, str, lineno)
-     int num;
-     char *str;
-     unsigned long lineno;
+void input_error(int num,
+		 char *str,
+		 unsigned long lineno)
 {
   error("Error at input line %lu: %s", lineno, str);
 }
 
 static
-void do_file(fp, tablep)
-     FILE *fp;
-     struct replacement_table *tablep;
+void do_file(FILE *fp,
+	     struct replacement_table *tablep)
 {
   struct sgmls *sp;
   struct sgmls_event e;
@@ -116,9 +114,8 @@ void do_file(fp, tablep)
 }
 
 static
-void output_data(v, n)
-struct sgmls_data *v;
-int n;
+void output_data(struct sgmls_data *v,
+		 int n)
 {
   int i;
 
@@ -131,18 +128,16 @@ int n;
 }
 
 static
-void output_pi(s, len)
-     char *s;
-     unsigned len;
+void output_pi(char *s,
+	       unsigned len)
 {
   for (; len > 0; len--, s++)
     output_data_char(*s);
 }
 
 static
-void output_replacement(repl, attributes)
-struct replacement *repl;
-struct sgmls_attribute *attributes;
+void output_replacement(struct replacement *repl,
+			struct sgmls_attribute *attributes)
 {
   struct replacement_item *p;
   struct sgmls_attribute *a;
@@ -175,8 +170,7 @@ struct sgmls_attribute *attributes;
 }
 
 static
-void output_attribute(p)
-struct sgmls_attribute *p;
+void output_attribute(struct sgmls_attribute *p)
 {
   switch (p->type) {
   case SGMLS_ATTR_IMPLIED:
@@ -224,16 +218,14 @@ struct sgmls_attribute *p;
 }
 
 static
-void output_token(s)
-     char *s;
+void output_token(char *s)
 {
   for (; *s; s++)
     output_char(*s);
 }
 
 static
-void output_data_char(c)
-     int c;
+void output_data_char(int c)
 {
   if (c != RSCHAR) {
     if (c == RECHAR)
